#[repr(C)]pub struct XmtpFfiListConversationsOptions {
pub conversation_type: i32,
pub limit: i64,
pub created_after_ns: i64,
pub created_before_ns: i64,
pub last_activity_after_ns: i64,
pub last_activity_before_ns: i64,
pub consent_states: *const i32,
pub consent_states_count: i32,
pub order_by: i32,
pub include_duplicate_dms: i32,
}Expand description
Options for listing conversations.
Fields
conversation_type: i32Conversation type filter: -1 = all, 0 = DM, 1 = Group.
limit: i64Maximum number of conversations to return. 0 = no limit.
created_after_ns: i64Only include conversations created after this timestamp (ns). 0 = no filter.
created_before_ns: i64Only include conversations created before this timestamp (ns). 0 = no filter.
last_activity_after_ns: i64Only include conversations with last activity after this timestamp (ns). 0 = no filter.
last_activity_before_ns: i64Only include conversations with last activity before this timestamp (ns). 0 = no filter.
consent_states: *const i32Consent state filter (parallel array with consent_states_count).
Values: 0 = Unknown, 1 = Allowed, 2 = Denied.
consent_states_count: i32Number of consent states in the filter. 0 = no filter.
order_by: i32Order by: 0 = CreatedAt (default), 1 = LastActivity.
include_duplicate_dms: i32Whether to include duplicate DMs. 0 = no (default), 1 = yes.